@@ -5,6 +5,11 @@ $Monitoring::GLPlugin::SNMP::MibsAndOids::origin->{'HP-ICF-CHASSIS-MIB'} = {
   name => 'HP-ICF-CHASSIS-MIB',
 };
 
+$Monitoring::GLPlugin::SNMP::MibsAndOids::mib_ids->{'HP-ICF-CHASSIS-MIB'} =
+  '1.3.6.1.4.1.11.2.14.11.1.2.6';
+# sensor-table, because lots of oids will be superseeded by std. entity-mib
+# However, the hpicfSensorTable will still be valid.
+
 $Monitoring::GLPlugin::SNMP::MibsAndOids::mibs_and_oids->{'HP-ICF-CHASSIS-MIB'} = {
   'hpicfSensorTable' => '1.3.6.1.4.1.11.2.14.11.1.2.6',
   'hpicfSensorEntry' => '1.3.6.1.4.1.11.2.14.11.1.2.6.1',
